@@ -3,6 +3,7 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 from enum import Enum, auto
+from optparse import Option
 from typing import List, Optional
 
 
@@ -214,6 +215,16 @@ class UserDefinedField:
             valueType=UdfType(dictionary.get("valueType", UdfType.String)),
         )
 
+    @property
+    def robot_tag(self) -> Optional[str]:
+        if self.valueType == UdfType.Enumeration:
+            return f"{self.name}:{self.value}"
+        elif self.valueType == UdfType.String and self.value:
+            return f"{self.name}:{self.value}"
+        elif self.valueType == UdfType.Boolean and self.value == "true":
+            return self.name
+        return None
+
 
 @dataclass
 class Keyword:
