@@ -39,6 +39,7 @@ from .utils import PathResolver
 
 SEPARATOR = "    "
 ROBOT_PATH_SEPARATOR = "/"
+RELATIVE_RESOURCE_INDICATOR = r"^{root}"
 SECTION_SEPARATOR = [EmptyLine.from_params()] * 2
 TESTCASE_SEPARATOR = [EmptyLine.from_params()]
 
@@ -375,10 +376,10 @@ class RobotSuiteFileBuilder:
     def _create_rf_resource_imports(self, import_dict: Dict[str, Set[str]]) -> List[ResourceImport]:
         resources = {
             str(resource)
-            for resource_root, resources in import_dict.items() for resource in resources
+            for resource_root, resources in import_dict.items()
+            for resource in resources
             if self._is_resource(resource_root)
         }
-
         resources.update(self.config.forcedImport.resources)
         resource_paths = {
             self._create_resource_path(resource) for resource in sorted(resources)
@@ -388,6 +389,8 @@ class RobotSuiteFileBuilder:
     def _create_resource_path(self, resource: str) -> str:
         if not self.config.resourceDirectory:
             return f"{resource}.resource"
+        if not re.match(RELATIVE_RESOURCE_INDICATOR, self.config.resourceDirectory):
+            return f"{self.config.resourceDirectory}{ROBOT_PATH_SEPARATOR}{resource}.resource"
         resource_dir = self._get_resource_directory()
         resource_path = self.config.subdivisionsMapping.resources.get(resource)
         resource_base_path = (
@@ -401,7 +404,7 @@ class RobotSuiteFileBuilder:
         root_path = Path(os.curdir).absolute()
         return os.path.relpath(
             re.sub(
-                r"^{root}",
+                RELATIVE_RESOURCE_INDICATOR,
                 str(root_path).replace('\\', '\\\\'),
                 self.config.resourceDirectory,
                 flags=re.IGNORECASE,
@@ -421,8 +424,9 @@ class RobotSuiteFileBuilder:
 
     def _create_rf_library_imports(self, import_dict: Dict[str, Set[str]]) -> List[LibraryImport]:
         libraries = {
-            next(iter(library))
-            for library_root, library in import_dict.items()
+            str(library)
+            for library_root, libraries in import_dict.items()
+            for library in libraries
             if self._is_library(library_root)
         }
         libraries.update(self.config.forcedImport.libraries)
